@@ -153,146 +153,6 @@ there:
 
 }/*C_HAS_PATH*/
 
-SEXP how_many_cycles(SEXP from, SEXP to, SEXP amat, SEXP nrows, SEXP nodes, SEXP debug) {
-
-int start = INT(from) - 1, stop = INT(to) - 1, n = INT(nrows);
-int *counter = NULL, *path = NULL, *a = NULL;
-int path_pos = 0, cur = start, cycle_counter = 0;
-int i = 0, a1 = 0, a2 = 0;
-int *debuglevel = NULL;
-SEXP res;
-
-  /* dereference the debug parameter. */
-  debuglevel = LOGICAL(debug);
-
-  /* initialize the position counters for the rows of the adjacency matrix. */
-  counter = alloc1dcont(n);
-  /* initialize the path array. */
-  path = alloc1dcont(n);
-
-  /* allocate the result. */
-  PROTECT(res = allocVector(INTSXP, 1));
-  INT(res) = 0;
-
-  /* map the adjacency matrix. */
-  a = INTEGER(amat);
-  /* back up and remove any arc between "start" and "stop".  */
-  a1 = a[CMC(start, stop, n)];
-  a2 = a[CMC(stop, start, n)];
-  a[CMC(start, stop, n)] = a[CMC(stop, start, n)] = 0;
-
-  while (1) {
-
-    if (*debuglevel > 0)
-      Rprintf("* currently at '%s'.\n", NODE(cur));
-
-there:
-
-    /* find the next child of the 'cur' node. */
-    for (i = 0; (i < n) && (counter[cur] < n); i++) {
-
-      if (a[CMC(cur, counter[cur], n)] != 0)
-        break;
-
-      counter[cur]++;
-
-    }/*FOR*/
-
-    if (cur == stop) {
-
-      cycle_counter++;
-
-      if (*debuglevel > 0) {
-
-        Rprintf("  @ found node '%s' ! cycle counter is now %d.\n",
-          NODE(stop), cycle_counter);
-        Rprintf("  @ the cycle is:\n'%s' ", NODE(stop));
-        for (int i = 0; i < path_pos ; i ++)
-          Rprintf("'%s' ", NODE(path[i]));
-        Rprintf("'%s' \n", NODE(cur));
-
-      }/*THEN*/
-
-      /* do not go on on this path. */
-      if (counter[cur] < n)
-        counter[cur]++;
-      cur = path[--path_pos];
-      path[path_pos + 1] = 0;
-
-    }/*THEN*/
-    else if (counter[cur] == n) {
-
-      /* the column indexes range from 0 to n - 1;  counter value of n means
-       * that all the children of that node has beeen visited.  */
-
-      /* if this node is the first one in the path, there search is finished
-       * and the 'stop' node was not found; return FALSE.*/
-      if  (path_pos == 0) {
-
-        INT(res) = cycle_counter;
-        UNPROTECT(1);
-
-        /* restore the original values in the adjacency matrix. */
-        a[CMC(start, stop, n)] = a1;
-        a[CMC(stop, start, n)] = a2;
-
-        return res;
-
-      }/*THEN*/
-
-      if (*debuglevel > 0) {
-
-        Rprintf("  > node '%s' has no more children, going back to '%s'.\n",
-          NODE(cur), NODE(path[path_pos - 1]));
-
-      }/*THEN*/
-
-      /* this node has no more children, skip back to the previous one. */
-      cur = path[--path_pos];
-      path[path_pos + 1] = 0;
-
-    }/*THEN*/
-    else {
-
-      /* inrement the counter to get to the next node to check, unless
-       * that one was the last. */
-      if (counter[cur] < n)
-        counter[cur]++;
-
-      /* do not visit an already visited node */
-      for (i = path_pos - 1; i >= 0; i--) {
-
-        if ((counter[cur] - 1) == path[i]) {
-
-          if (*debuglevel > 0) {
-
-            Rprintf("  @ node '%s' already visited, skipping.\n", NODE(path[i]));
-
-          }/*THEN*/
-
-          goto there;
-
-        }/*THEN*/
-
-      }/*FOR*/
-
-      /* update the path. */
-      path[path_pos++] = cur;
-      /* the current node is now the children we have just found. */
-      cur = counter[cur] - 1;
-
-      if (*debuglevel > 0) {
-
-        Rprintf("  > jumping to '%s'.\n", NODE(cur));
-
-      }/*THEN*/
-
-    }/*ELSE*/
-
-  }/*WHILE*/
-
-}/*HOW_MANY_CYCLES*/
-
 int c_directed_path(int start, int stop, int *amat, int n, SEXP nodes,
     int debuglevel) {
 
